@@ -117,7 +117,8 @@ def make_server_request(
                 msg = "Cannot find the specified object"
                 msg += f"\n\n{err_msg}"
                 raise NotFound(msg) from None
-            msg = "Cannot read answer from server."
+
+            msg = f"Cannot read answer from server {url}"
             msg += "\n\n" + indent(err_msg, "  > ")
             raise ConnectionError(msg) from e
 
@@ -126,6 +127,12 @@ def make_server_request(
             msg += "\n\n" + indent(err_msg, "  > ")
             raise ConnectionError(msg) from e
 
+
+        if e.code == 400:
+            msg = "Invalid request to server."
+            msg += f"\n\n{received_msg}"
+            raise RequestFailed(msg) from None
+
         if e.code == 401:
             msg = "Not authorized to perform operation."
             msg += f"\n\n{received_msg}"
