@@ -1,6 +1,5 @@
 from dataclasses import dataclass
-from datetime import datetime
-from typing import Dict, List, Optional
+from typing import Dict, List, NewType, Optional
 
 import dateutil.parser
 import termcolor
@@ -8,10 +7,13 @@ import termcolor
 from duckietown_challenges import ChallengesConstants
 from duckietown_challenges.challenge import ChallengeDescription
 from duckietown_challenges.utils import pad_to_screen_length
+from zuper_commons.timing import now_utc
 from .rest import make_server_request
 
 Endpoints = ChallengesConstants.Endpoints
 
+SubmissionID = NewType('SubmissionID', int)
+UserID = NewType('UserID', int)
 
 @dataclass
 class RegistryInfo:
@@ -23,7 +25,9 @@ def add_impersonate_info(data, impersonate):
         data["impersonate"] = impersonate
 
 
-def dtserver_challenge_define(token: str, yaml, force_invalidate: bool, impersonate: int=None):
+def dtserver_challenge_define(
+    token: str, yaml, force_invalidate: bool, impersonate: Optional[UserID] = None
+):
     endpoint = Endpoints.challenge_define
     method = "POST"
     data = {"yaml": yaml, "force-invalidate": force_invalidate}
@@ -32,7 +36,7 @@ def dtserver_challenge_define(token: str, yaml, force_invalidate: bool, imperson
     return make_server_request(token, endpoint, data=data, method=method, timeout=15)
 
 
-def get_registry_info(token: str, impersonate: int=None) -> RegistryInfo:
+def get_registry_info(token: str, impersonate: Optional[UserID] = None) -> RegistryInfo:
     endpoint = Endpoints.registry_info
     method = "GET"
     data = {}
@@ -44,7 +48,7 @@ def get_registry_info(token: str, impersonate: int=None) -> RegistryInfo:
     return ri
 
 
-def dtserver_auth(token, cmd, impersonate=None):
+def dtserver_auth(token, cmd, impersonate: Optional[UserID] = None):
     endpoint = Endpoints.auth
     method = "GET"
     data = {"query": cmd}
@@ -54,7 +58,7 @@ def dtserver_auth(token, cmd, impersonate=None):
     return res
 
 
-def get_dtserver_user_info(token, impersonate=None):
+def get_dtserver_user_info(token, impersonate: Optional[UserID] = None):
     """ Returns a dictionary with information about the user """
     endpoint = Endpoints.user_info
     method = "GET"
@@ -73,7 +77,7 @@ def get_dtserver_user_info(token, impersonate=None):
 #     return make_server_request(token, endpoint, data=data, method=method)
 
 
-def dtserver_retire(token, submission_id, impersonate=None):
+def dtserver_retire(token, submission_id: SubmissionID, impersonate: Optional[UserID] = None):
     endpoint = Endpoints.submissions
     method = "DELETE"
     data = {"submission_id": submission_id}
@@ -82,7 +86,16 @@ def dtserver_retire(token, submission_id, impersonate=None):
     return make_server_request(token, endpoint, data=data, method=method)
 
 
-def dtserver_get_user_submissions(token, impersonate=None):
+def dtserver_retire_same_label(token, label: str, impersonate: Optional[UserID] = None):
+    endpoint = Endpoints.submissions
+    method = "DELETE"
+    data = {"label": label}
+    add_version_info(data)
+    add_impersonate_info(data, impersonate)
+    return make_server_request(token, endpoint, data=data, method=method)
+
+
+def dtserver_get_user_submissions(token, impersonate: Optional[UserID] = None):
     """ Returns a dictionary with information about the user submissions """
     endpoint = Endpoints.submissions
     method = "GET"
@@ -97,7 +110,7 @@ def dtserver_get_user_submissions(token, impersonate=None):
     return submissions
 
 
-def dtserver_submit2(*, token, challenges: List[str], data, impersonate=None):
+def dtserver_submit2(*, token, challenges: List[str], data, impersonate: Optional[UserID] = None):
     if not isinstance(challenges, list):
         msg = "Expected a list of strings, got %s" % challenges
         raise ValueError(msg)
@@ -109,7 +122,7 @@ def dtserver_submit2(*, token, challenges: List[str], data, impersonate=None):
     return make_server_request(token, endpoint, data=data, method=method)
 
 
-def dtserver_get_info(token, submission_id, impersonate=None):
+def dtserver_get_info(token, submission_id: SubmissionID, impersonate: Optional[UserID] = None):
     endpoint = Endpoints.submission_single + "/%s" % submission_id
     method = "GET"
     data = {}
@@ -120,7 +133,7 @@ def dtserver_get_info(token, submission_id, impersonate=None):
     )
 
 
-def dtserver_reset_submission(token, submission_id, step_name, impersonate=None):
+def dtserver_reset_submission(token, submission_id: SubmissionID, step_name, impersonate: Optional[UserID] = None):
     endpoint = Endpoints.reset_submission
     method = "POST"
     data = {"submission_id": submission_id, "step_name": step_name}
@@ -129,7 +142,7 @@ def dtserver_reset_submission(token, submission_id, step_name, impersonate=None)
     return make_server_request(token, endpoint, data=data, method=method)
 
 
-def dtserver_reset_job(token, job_id, impersonate=None):
+def dtserver_reset_job(token, job_id, impersonate: Optional[UserID] = None):
     endpoint = Endpoints.reset_job
     method = "POST"
     data = {"job_id": job_id}
@@ -149,7 +162,7 @@ def dtserver_report_job(
     uploaded,  # <- uploaded via S3
     timeout,  # <- how long to wait for the server
     ipfs_hashes: Dict[str, str],  # <- IPFS files
-    impersonate=None,
+    impersonate: Optional[UserID] = None,
 ):
     """
 
@@ -192,7 +205,7 @@ def dtserver_work_submission(
     features,
     reset,
     timeout,
-    impersonate=None,
+    impersonate: Optional[UserID] = None,
 ):
     """
 
@@ -259,7 +272,7 @@ def dtserver_work_submission(
 
 
 def get_challenge_description(
-    token, challenge_name: str, impersonate=None
+    token, challenge_name: str, impersonate: Optional[UserID] = None
 ) -> ChallengeDescription:
     if not isinstance(challenge_name, str):
         msg = "Expected a string for the challenge name, I got %s" % challenge_name
@@ -274,7 +287,7 @@ def get_challenge_description(
     return cd
 
 
-def dtserver_get_challenges(token, impersonate=None) -> Dict[int, ChallengeDescription]:
+def dtserver_get_challenges(token, impersonate: Optional[UserID] = None) -> Dict[int, ChallengeDescription]:
     endpoint = Endpoints.challenges
     method = "GET"
     data = {}
@@ -338,7 +351,7 @@ def dtserver_get_compatible_challenges(
     for challenge_id in S:
         cd = challenges[challenge_id]
         challenge_name = cd.name
-        is_open = cd.date_open < datetime.now() < cd.date_close
+        is_open = cd.date_open < now_utc() < cd.date_close
         if not is_open:
             continue
 
@@ -362,7 +375,7 @@ def dtserver_get_compatible_challenges(
     for challenge_id, challenge in challenges.items():
         if challenge.closure:
             others = ", ".join(map(q, challenge.closure))
-            msg = f'* Submitting to {q(challenge.name)} will also submit to: {others}.'
+            msg = f"* Submitting to {q(challenge.name)} will also submit to: {others}."
             print(msg)
     print("")
     return CompatibleChallenges(res, compatible)
