@@ -3,6 +3,7 @@ import json
 import math
 import os
 import re
+import yaml
 
 import decorator
 
@@ -26,7 +27,8 @@ def write_data_to_file(data, filename):
     d8n_make_sure_dir_exists(filename)
 
     if os.path.exists(filename):
-        current = open(filename).read()
+        with open(filename) as _:
+            current = _.read()
         if current == data:
             if not "assets/" in filename:
                 dclogger.debug("already up to date %s" % filename)
@@ -144,7 +146,6 @@ def wrap_config_reader2(f, cls, data: dict, *args, **kwargs):
 
 
 def safe_yaml_dump(x, **args):
-    import yaml
 
     s = yaml.safe_dump(x, encoding="utf-8", indent=4, allow_unicode=True, **args)
     return s
